@@ -25,6 +25,7 @@ import logging
 
 from oslo_concurrency import lockutils
 from oslo_utils import excutils
+from oslo_utils import reflection
 import six
 
 from oslo_vmware._i18n import _, _LE, _LI, _LW
@@ -82,9 +83,9 @@ class RetryDecorator(object):
         self._sleep_time = 0
 
     def __call__(self, f):
+        func_name = reflection.get_callable_name(f)
 
         def _func(*args, **kwargs):
-            func_name = f.__name__
             result = None
             try:
                 if self._retry_count:
@@ -95,11 +96,11 @@ class RetryDecorator(object):
                 result = f(*args, **kwargs)
             except self._exceptions:
                 with excutils.save_and_reraise_exception() as ctxt:
-                    LOG.warn(_LW("Exception which is in the suggested list of "
-                                 "exceptions occurred while invoking function:"
-                                 " %s."),
-                             func_name,
-                             exc_info=True)
+                    LOG.warning(_LW("Exception which is in the suggested list "
+                                    "of exceptions occurred while invoking "
+                                    "function: %s."),
+                                func_name,
+                                exc_info=True)
                     if (self._max_retry_count != -1 and
                             self._retry_count >= self._max_retry_count):
                         LOG.error(_LE("Cannot retry upon suggested exception "
@@ -118,7 +119,7 @@ class RetryDecorator(object):
         def func(*args, **kwargs):
             loop = loopingcall.DynamicLoopingCall(_func, *args, **kwargs)
             evt = loop.start(periodic_interval_max=self._max_sleep_time)
-            LOG.debug("Waiting for function %s to return.", f.__name__)
+            LOG.debug("Waiting for function %s to return.", func_name)
             return evt.wait()
 
         return func
@@ -494,8 +495,8 @@ class VMwareAPISession(object):
                                    lease,
                                    'error')
         except exceptions.VimException:
-            LOG.warn(_LW("Error occurred while reading error message for "
-                         "lease: %s."),
-                     lease,
-                     exc_info=True)
+            LOG.warning(_LW("Error occurred while reading error message for "
+                            "lease: %s."),
+                        lease,
+                        exc_info=True)
             return "Unknown"
