@@ -112,7 +112,7 @@ class FileHandle(object):
             LOG.exception(excep_msg)
             raise exceptions.VimException(excep_msg, excep)
 
-    def _create_write_connection(self, url,
+    def _create_write_connection(self, method, url,
                                  file_size=None,
                                  cookies=None,
                                  overwrite=None,
@@ -125,7 +125,8 @@ class FileHandle(object):
                   {'file_size': file_size,
                    'url': url})
         try:
-            conn = self._create_connection(url, 'PUT', cacerts, ssl_thumbprint)
+            conn = self._create_connection(url, method, cacerts,
+                                           ssl_thumbprint)
             headers = {'User-Agent': USER_AGENT}
             if file_size:
                 headers.update({'Content-Length': str(file_size)})
@@ -151,8 +152,8 @@ class FileHandle(object):
         try:
             self._file_handle.close()
         except Exception:
-            LOG.warn(_LW("Error occurred while closing the file handle"),
-                     exc_info=True)
+            LOG.warning(_LW("Error occurred while closing the file handle"),
+                        exc_info=True)
 
     def _build_vim_cookie_header(self, vim_cookies):
         """Build ESX host session cookie header."""
@@ -241,7 +242,8 @@ class FileWriteHandle(FileHandle):
     """Write handle for a file in VMware server."""
 
     def __init__(self, host, port, data_center_name, datastore_name, cookies,
-                 file_path, file_size, scheme='https', cacerts=False):
+                 file_path, file_size, scheme='https', cacerts=False,
+                 thumbprint=None):
         """Initializes the write handle with given parameters.
 
         :param host: ESX/VC server IP address or host name
@@ -253,6 +255,8 @@ class FileWriteHandle(FileHandle):
         :param file_path: datastore path where the file is written
         :param file_size: size of the file in bytes
         :param scheme: protocol-- http or https
+        :param cacerts: CA bundle file to use for SSL verification
+        :param thumbprint: expected SHA1 thumbprint of server's certificate
         :raises: VimConnectionException, ValueError
         """
         soap_url = self._get_soap_url(scheme, host, port)
@@ -260,10 +264,12 @@ class FileWriteHandle(FileHandle):
         self._url = '%s/folder/%s' % (soap_url, file_path)
         self._url = self._url + '?' + urlparse.urlencode(param_list)
 
-        self._conn = self._create_write_connection(self._url,
+        self._conn = self._create_write_connection('PUT',
+                                                   self._url,
                                                    file_size,
                                                    cookies=cookies,
-                                                   cacerts=cacerts)
+                                                   cacerts=cacerts,
+                                                   ssl_thumbprint=thumbprint)
         FileHandle.__init__(self, self._conn)
 
     def write(self, data):
@@ -294,8 +300,8 @@ class FileWriteHandle(FileHandle):
         try:
             self._conn.getresponse()
         except Exception:
-            LOG.warn(_LW("Error occurred while reading the HTTP response."),
-                     exc_info=True)
+            LOG.warning(_LW("Error occurred while reading the HTTP response."),
+                        exc_info=True)
         super(FileWriteHandle, self).close()
 
     def __str__(self):
@@ -310,7 +316,7 @@ class VmdkWriteHandle(FileHandle):
     """
 
     def __init__(self, session, host, port, rp_ref, vm_folder_ref, import_spec,
-                 vmdk_size):
+                 vmdk_size, http_method='PUT'):
         """Initializes the VMDK write handle with input parameters.
 
         :param session: valid API session to ESX/VC server
@@ -321,6 +327,7 @@ class VmdkWriteHandle(FileHandle):
                               of backing VM
         :param import_spec: import specification of the backing VM
         :param vmdk_size: size of the backing VM's VMDK file
+        :param http_method: either PUT or POST
         :raises: VimException, VimFaultException, VimAttributeException,
                  VimSessionOverLoadException, VimConnectionException,
                  ValueError
@@ -348,12 +355,20 @@ class VmdkWriteHandle(FileHandle):
 
         cookies = session.vim.client.options.transport.cookiejar
         # Create HTTP connection to write to VMDK URL
-        octet_stream = 'binary/octet-stream'
-        self._conn = self._create_write_connection(self._url,
+        if http_method == 'PUT':
+            overwrite = 't'
+            content_type = 'binary/octet-stream'
+        elif http_method == 'POST':
+            overwrite = None
+            content_type = 'application/x-vnd.vmware-streamVmdk'
+        else:
+            raise ValueError('http_method must be either PUT or POST')
+        self._conn = self._create_write_connection(http_method,
+                                                   self._url,
                                                    vmdk_size,
                                                    cookies=cookies,
-                                                   overwrite='t',
-                                                   content_type=octet_stream,
+                                                   overwrite=overwrite,
+                                                   content_type=content_type,
                                                    ssl_thumbprint=thumbprint)
         FileHandle.__init__(self, self._conn)
 
@@ -458,9 +473,10 @@ class VmdkWriteHandle(FileHandle):
                           {'url': self._url,
                            'state': state})
         except exceptions.VimException:
-            LOG.warn(_LW("Error occurred while releasing the lease for %s."),
-                     self._url,
-                     exc_info=True)
+            LOG.warning(_LW("Error occurred while releasing the lease "
+                            "for %s."),
+                        self._url,
+                        exc_info=True)
         super(VmdkWriteHandle, self).close()
         LOG.debug("Closed VMDK write handle for %s.", self._url)
 
@@ -596,9 +612,10 @@ class VmdkReadHandle(FileHandle):
                           {'url': self._url,
                            'state': state})
         except exceptions.VimException:
-            LOG.warn(_LW("Error occurred while releasing the lease for %s."),
-                     self._url,
-                     exc_info=True)
+            LOG.warning(_LW("Error occurred while releasing the lease "
+                            "for %s."),
+                        self._url,
+                        exc_info=True)
             raise
         super(VmdkReadHandle, self).close()
         LOG.debug("Closed VMDK read handle for %s.", self._url)
